.. image:: https://travis-ci.org/bielbienne/bst.pygasus.demo.svg?branch=master
    :target: https://travis-ci.org/bielbienne/bst.pygasus.demo


.. contents::

Introduction
============

This package is a part of the 
`Pygasus framework <https://github.com/bielbienne/bst.pygasus.core>`_, 
a python persistance layer and provider of generic functionality 
for ExtJs based (web) applications.

bst.pygasus and all corresponding submodules are licensed under the ZPL 2.1, see LICENSE.txt for details.


References
==========

Main readme
    https://github.com/bielbienne/bst.pygasus.core

Demonstration application
    https://github.com/bielbienne/bst.pygasus.demo

Our projects and future plans with the Pygasus framework
    https://foss.biel-bienne.ch/


About us
========
We are the IT Services of Biel/Bienne, Switzerland.
http://foss.biel-bienne.ch/blog/
